netapp_ontap.models.share_acl API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.share_acl`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ShareAclSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ShareAcl object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `links: SelfLink GET`

    The links field of the share_acl.

  `permission: str GET POST PATCH`

    Specifies the access rights that a user or group has on the defined CIFS Share. The following values are allowed:

    - no_access - User does not have CIFS share access
    - read - User has only read access
    - change - User has change access
    - full_control - User has full_control access

    Valid choices:

    - no_access
    - read
    - change
    - full_control
  `type: str GET POST`

    Specifies the type of the user or group to add to the access control list of a CIFS share. The following values are allowed:

    - windows - Windows user or group
    - unix_user - UNIX user
    - unix_group - UNIX group

    Valid choices:

    - windows
    - unix_user
    - unix_group
  `user_or_group: str GET POST`

    Specifies the user or group name to add to the access control list of a CIFS share.

    Example: ENGDOMAIN\ad_user

  `win_sid_unix_id: str GET`

    Windows SID/UNIX ID depending on access-control type.